==> haskell-prettyprinter-ansi-terminal-1.1.1.2-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-ansi-terminal
version: 1.1.1.2
id: prettyprinter-ansi-terminal-1.1.1.2-CtbJIqvcTzNIZUsrIe61se
key: prettyprinter-ansi-terminal-1.1.1.2-CtbJIqvcTzNIZUsrIe61se
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: ANSI terminal backend for the »prettyprinter« package.
description:
    See README.md
category: User Interfaces, Text
abi: a87555628e5c8d9c3b6fae870ffb829e
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/prettyprinter-ansi-terminal-1.1.1.2
hs-libraries: HSprettyprinter-ansi-terminal-1.1.1.2-CtbJIqvcTzNIZUsrIe61se
depends:
    base-4.11.1.0 ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    text-1.2.3.0 prettyprinter-1.2.1-PxuDMo9T75GnmarR3X2DE
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             prettyprinter-1.2.1-PxuDMo9T75GnmarR3X2DE=c4483e857b7077e03364781f441f7e5d
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-ansi-terminal-1.1.1.2-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-ansi-terminal
version: 1.1.1.2
id: prettyprinter-ansi-terminal-1.1.1.2-85snbhHZ7mVApsJANLk1bh
key: prettyprinter-ansi-terminal-1.1.1.2-85snbhHZ7mVApsJANLk1bh
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: ANSI terminal backend for the »prettyprinter« package.
description:
    See README.md
category: User Interfaces, Text
abi: 9d00cf3add102cd7432d70f541c94fb2
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-ansi-terminal-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/prettyprinter-ansi-terminal-1.1.1.2
hs-libraries: HSprettyprinter-ansi-terminal-1.1.1.2-85snbhHZ7mVApsJANLk1bh
depends:
    base-4.11.1.0 ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    text-1.2.3.0 prettyprinter-1.2.1-C1spnh8spPLAXAJTycVnbI
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             prettyprinter-1.2.1-C1spnh8spPLAXAJTycVnbI=c6bd9c9a96f651deb1a3185f07d727e5
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
